/*
 * The plugin.groovy file is used to describe the plugin's targets, ant task, and runtime configuration.
 * 
 * Structure:
 * 	The plugin.groovy file is structured as a series of nested elements, the top element being project.
 *
 * 	The project element has a nested targets element.
 *
 * 	The targets element can contain multiple target elements each having unique names.
 *
 * 	Each uniquely named target element contains a nested ant task element, this name should 
 * 	relate to an ant task that already exists in the ant project at plugin invocation.
 *
 * 	The ant task element contains a set of name value pairs relating to runtime information required
 * 	by the PluginTargetCreationStrategy, the current groovy implementation only requires 1 name value pair.
 * 
 * Delegate:
 * 	The delegate property inside the groovy ant task element needs to have a value of the fully qualified 
 * 	class name of the delegate class that will perform the processing functions provided by the plugin.
 * 
 */

project{
	targets{
		
		/*
		 * The doCheckstyle target specifies an ant task of groovy as the delegate class is written in groovy.
		 * It also specifies a delegate value of the fully qualified class name of the CheckstyleDelegate class.
		 * 
		 */
		doCheckstyle{
			/*
			 * This ant task element is the groovy ant task that already exists in the ant project
			 * @param delegate	Fully qualified delegate class name
			 */
			groovy{
				bean = "org.openscm.kundo.plugins.CheckstyleDelegate"
			}
		}
	}
}